==> pluxml_5.3.orig.tar.gz: PluXml-5.3/core/lang/fr/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Enregistrement des données effectué avec succès',
'L_UPDATE_TITLE'					=> 'Mise à jour PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml requiert PHP 5 ou superieur pour fonctionner.',

'L_SELECT_LANG'						=> 'Sélectionnez votre langue',
'L_INPUT_CHANGE'					=> 'Changer',

'L_UPDATE_UPTODATE'					=> 'Votre PluXml est déjà à jour.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Aucune mise à jour n\'est disponible.',
'L_UPDATE_BACK'						=> 'Revenir au site',
'L_UPDATE_WARNING1'					=> 'Vous allez mettre à jour votre ancienne version de PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Veuillez sélectionner dans la liste ci-dessous votre ancienne version de PluXml à mettre à jour.',
'L_UPDATE_WARNING2'					=> 'Si votre ancienne version n\'est pas listée ici, c\'est qu\'il n\'existe pas de procédure automatisée de mise à jour car votre version est trop vieille.<br />Nous vous suggérons de télécharger la dernière version de <a href="http://www.pluxml.org">PluXml</a> et de faire une nouvelle installation.',
'L_UPDATE_WARNING3'					=> 'Attention, avant de démarrer la mise à jour, n\'oubliez pas de faire une sauvegarde de vos données en faisant une copie du dossier "data"',
'L_UPDATE_START'					=> 'Démarrer la mise à jour',

'L_UPDATE_ENDED'					=> 'Mise à jour de la version %s terminée.',
'L_UPDATE_INPROGRESS'				=> 'Applications des mises à jour version',
'L_UPDATE_ERROR'					=> 'Une erreur s\'est produite pendant la mise à jour.',
'L_UPDATE_SUCCESSFUL'				=> 'Toutes les mises à jour ont été appliquées avec succès !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Mise à jour du fichier parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Création du fichier tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Erreur pendant la création du fichier tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Création du fichier thème',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Erreur pendant la création du fichier',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Conversion des articles au nouveau format',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Erreur pendant le traitement du fichier',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migration du fichier des pages statiques',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Erreur pendant la migration du fichier des pages statiques',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Création du fichier des utilisateurs',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Erreur pendant la création du fichier des utilisateurs',
'L_UPDATE_USERS_MIGRATION'			=> 'Migration du fichier des utilisateurs',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Erreur pendant la migration du fichier des utilisateurs',
'L_UPDATE_ERR_NO_USERS'				=> 'Aucun utilisateur présent dans le fichier',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Création du fichier .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Erreur pendant la création du fichier .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Mise à jour du fichier .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Erreur pendant la mise à jour du fichier .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migration du fichier des catégories',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Erreur pendant la migration du fichier des catégories',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Création du fichier plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Erreur pendant la création du fichier plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Suppression du fichier core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Erreur pendant la suppression du fichier core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Suppression du dossier core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Erreur pendant la suppression du dossier core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Mise à jour du fichier',
'L_UPDATE_ERR_FILE'					=> 'Erreur pendant la mise à jour du fichier',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migration des fichiers de paramètrage des plugins dans le dossier de configuration',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Mise à jour du fichier plugins.xml',

);
?>

==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/fr/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Enregistrement des données effectué avec succès',
'L_UPDATE_TITLE'					=> 'Mise à jour PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml requiert PHP 5 ou supérieur pour fonctionner.',

'L_SELECT_LANG'						=> 'Sélectionnez votre langue',
'L_INPUT_CHANGE'					=> 'Changer',

'L_UPDATE_UPTODATE'					=> 'Votre PluXml est déjà à jour.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Aucune mise à jour n\'est disponible.',
'L_UPDATE_BACK'						=> 'Revenir au site',
'L_UPDATE_WARNING1'					=> 'Vous allez mettre à jour votre ancienne version de PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Veuillez sélectionner dans la liste ci-dessous votre ancienne version de PluXml à mettre à jour.',
'L_UPDATE_WARNING2'					=> 'Si votre ancienne version n\'est pas listée ici, c\'est qu\'il n\'existe pas de procédure automatisée de mise à jour car votre version est trop vieille.<br />Nous vous suggérons de télécharger la dernière version de <a href="http://www.pluxml.org">PluXml</a> et de faire une nouvelle installation.',
'L_UPDATE_WARNING3'					=> 'Attention, avant de démarrer la mise à jour, n\'oubliez pas de faire une sauvegarde de vos données en faisant une copie du dossier "data"',
'L_UPDATE_START'					=> 'Démarrer la mise à jour',

'L_UPDATE_ENDED'					=> 'Mise à jour de la version %s terminée.',
'L_UPDATE_INPROGRESS'				=> 'Applications des mises à jour version',
'L_UPDATE_ERROR'					=> 'Une erreur s\'est produite pendant la mise à jour.',
'L_UPDATE_SUCCESSFUL'				=> 'Toutes les mises à jour ont été appliquées avec succès !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Mise à jour du fichier parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Création du fichier tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Erreur pendant la création du fichier tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Création du fichier thème',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Erreur pendant la création du fichier',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Conversion des articles au nouveau format',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Erreur pendant le traitement du fichier',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migration du fichier des pages statiques',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Erreur pendant la migration du fichier des pages statiques',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Création du fichier des utilisateurs',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Erreur pendant la création du fichier des utilisateurs',
'L_UPDATE_USERS_MIGRATION'			=> 'Migration du fichier des utilisateurs',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Erreur pendant la migration du fichier des utilisateurs',
'L_UPDATE_ERR_NO_USERS'				=> 'Aucun utilisateur présent dans le fichier',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Création du fichier .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Erreur pendant la création du fichier .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Mise à jour du fichier .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Erreur pendant la mise à jour du fichier .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migration du fichier des catégories',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Erreur pendant la migration du fichier des catégories',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Création du fichier plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Erreur pendant la création du fichier plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Suppression du fichier core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Erreur pendant la suppression du fichier core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Suppression du dossier core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Erreur pendant la suppression du dossier core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Mise à jour du fichier',
'L_UPDATE_ERR_FILE'					=> 'Erreur pendant la mise à jour du fichier',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migration des fichiers de paramétrage des plugins dans le dossier de configuration',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Mise à jour du fichier plugins.xml',

);
?>
